@@ -7,21 +7,24 @@ The specifications are responsible for sanitation, validation and normalisation.
 
 from input_algorithms.spec_base import (
       create_spec, defaulted, string_choice_spec
-    , dictionary_spec, string_spec, valid_string_spec, dictof, set_options, dict_from_bool_spec
+    , dictionary_spec, string_spec, valid_string_spec
     , listof, optional_spec, or_spec, any_spec
     , directory_spec, filename_spec, file_spec
     , boolean, required, formatted, overridden
-    , integer_spec
+    , integer_spec, dictof, dict_from_bool_spec
+    , container_spec
     )
 
-from harpoon.option_spec.image_specs import command_spec, link_spec, mount_spec, env_spec, port_spec
+from harpoon.option_spec.command_specs import command_spec
 from harpoon.formatter import MergedOptionStringFormatter
-from harpoon.option_spec import task_objs, image_objs
+from harpoon.option_spec.command_objs import Commands
 from harpoon.helpers import memoized_property
+from harpoon.option_spec import task_objs
 
 from input_algorithms.dictobj import dictobj
 from input_algorithms import validators
 
+import time
 import six
 
 class Harpoon(dictobj):
@@ -84,6 +87,8 @@ class HarpoonSpec(object):
     @memoized_property
     def image_spec(self):
         """Spec for each image"""
+        from harpoon.option_spec import image_specs as specs
+        from harpoon.option_spec import image_objs
         return create_spec(image_objs.Image
             # Change the context options
             , validators.deprecated_key("exclude_context", "Use ``context.exclude``")
@@ -109,14 +114,14 @@ class HarpoonSpec(object):
             , image_name_prefix = defaulted(string_spec(), "")
 
             , user = defaulted(string_spec(), None)
-            , mtime = any_spec()
+            , mtime = defaulted(any_spec(), time.time())
             , configuration = any_spec()
 
             # The spec itself
             , bash = optional_spec(formatted(string_spec(), formatter=MergedOptionStringFormatter))
             , command = optional_spec(formatted(string_spec(), formatter=MergedOptionStringFormatter))
-            , commands = required(command_spec())
-            , links = listof(link_spec(), expect=image_objs.Link)
+            , commands = required(container_spec(Commands, listof(command_spec())))
+            , links = listof(specs.link_spec(), expect=image_objs.Link)
 
             , context = dict_from_bool_spec(lambda meta, val: {"enabled": val}
                 , create_spec(image_objs.Context
@@ -133,7 +138,7 @@ class HarpoonSpec(object):
             , lxc_conf = defaulted(filename_spec(), None)
 
             , volumes = create_spec(image_objs.Volumes
-                , mount = listof(mount_spec(), expect=image_objs.Mount)
+                , mount = listof(specs.mount_spec(), expect=image_objs.Mount)
                 , share_with = listof(formatted(string_spec(), MergedOptionStringFormatter, expected_type=image_objs.Image))
                 )
 
@@ -143,8 +148,8 @@ class HarpoonSpec(object):
                   )
                 )
 
-            , env = listof(env_spec(), expect=image_objs.Environment)
-            , ports = listof(port_spec(), expect=image_objs.Port)
+            , env = listof(specs.env_spec(), expect=image_objs.Environment)
+            , ports = listof(specs.port_spec(), expect=image_objs.Port)
 
             , other_options = create_spec(other_options
                 , run = dictionary_spec()
